.. _sdv.metrics.timeseries:

sdv.metrics.timeseries
----------------------

.. currentmodule:: sdv.metrics.timeseries

.. autosummary::
   :toctree: api/

    TimeSeriesMetric
    TimeSeriesMetric.get_subclasses

Time Series Detection Metrics
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

    TimeSeriesDetectionMetric
    TimeSeriesDetectionMetric.get_subclasses
    LSTMDetection
    LSTMDetection.get_subclasses
    LSTMDetection.compute

Time Series Efficacy Metrics
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

    TimeSeriesEfficacyMetric
    TimeSeriesEfficacyMetric.get_subclasses
    LSTMClassifierEfficacy
    LSTMClassifierEfficacy.get_subclasses
    LSTMClassifierEfficacy.compute
